urlFor property

String Function(RequestOptions options)? urlFor
final

Optional override for the URL to record. Defaults to requestOptions.uri.toString(). Use this if you want to strip query strings, mask secrets in the path, or rewrite the host.

Implementation

final String Function(RequestOptions options)? urlFor;